%MCSException Capture MCS error information.
%   MCSME = MCSException(ME) wraps the MException object ME in a
%   MCSException object.
%
%   MCSException Methods:
%     throwAsCalled - Issue exception as if from called function in a TRY
%                     statement.
%
%   See also MException.

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.

classdef MCSException < MException
  properties
    mcsstack
    mcsreport
  end
  methods
    function mcsme = MCSException(me)
      if nargin == 0
        me = MException();
      end
        
      mcsme = mcsme@MException(me.identifier, me.message);
      mcsme.mcsreport = getReport(me);
      if ~isempty(me.stack)
        mcsme.mcsstack = me.stack;
      end
    end
    
    function throwAsCalled(mcsme)
      %throwAsCalled Issue exception as if from called function in a TRY statement.
      %   throwAsCalled(MCSME) throws an MException object MCSME. The exception
      %   MCSME should be based on an MException created by a CATCH statement.
      %   MATLAB exits the currently running function and returns control to
      %   either the keyboard or an enclosing CATCH block in a calling function.
      %   Unlike the THROW function, MATLAB omits the current stack frame from
      %   the STACK field of the MCSException, thus making the exception look as
      %   if it is being thrown by the function called in the TRY statement.
      %
      %   See also MException.throw, MException.throwAsCaller.
    
      errorStruct.message = mcsme.message;
      errorStruct.identifier = mcsme.identifier;
      if length(mcsme.mcsstack) > 1
        errorStruct.stack = mcsme.mcsstack(1:end-1);
      elseif length(mcsme.mcsstack) == 1
        errorStruct.stack = mcsme.mcsstack;
        errorStruct.stack(1).name = '';
        errorStruct.stack(1).line = 0;
      else
        errorStruct.stack = mcsme.mcsstack;
      end
      error(errorStruct)
    end
    
  end
end