%SBLOCK Abstract singular block class 
%   SBLOCK is an abstract canonical block class representing a singular
%   block structure. 
%
%   See also RSBLOCK, LSBLOCK, MBLOCK, SMBLOCK, MCSBLOCK.

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.

classdef sblock < mcsblock

  properties (Access = protected)
    m = 0;
    n = 0;
    blockv = [];
  end
  
  properties (Constant, Access = protected)
    type = 'singular'; 
  end
  
  methods
    function obj = set.blockv(obj,blk)
      % Check that block sizes are valid.
      
      if isempty(blk)
        obj.blockv = [];
        return
      end
      
      if ~isnumeric(blk) || ~isvector(blk) 
        error('MCS:sblock:StructInt','The structure integer partition must be a vector.');
      elseif size(blk,1) > 1
        blk = blk';
      end
      
      if ~isreal(blk) || any(rem(blk,1) ~= 0) || min(blk) < 0 
        error('MCS:sblock:BlockSize','The block sizes must be positive integer valued.');
      end
      obj.blockv = blk;
      obj = obj.updateSize;
    end
    %-------------------------------
  end
  
  methods (Abstract, Access = protected)
    obj = updateSize(obj);
  end
  
end % End classdef
