function [c] = cmcodim(varargin)
%CMCODIM Codimension of a matrix orbit under congruence.
%   CMCODIM(H) computes the codimension of the tangent space of the
%   congruence orbit of a matrix H. Default tolerance parameter of RANK
%   is used.
%
%   CMCODIM(H,Tol) uses the specified tolerance Tol. 
%
%   CMCODIM(CMstr) determines the codimension of the orbit of the congruence
%   matrix structure object CMstr. The codimension is determined with
%   respect to the represented canonical structure not the tangent space.
%   For further information, see CMSTRUCT/CODIM.
%
%   See also CMSTRUCT/CODIM, MCODIM.

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.
  
  nargoutchk(0,1);

  if isa(varargin{1},'cmstruct')
    c = codim(varargin{:});
  else
    narginchk(1,2);
    
    A = varargin{1};
    T = cmtanspace(A);
    if nargin == 1
      % Use default tolerance in rank
      c = size(T, 1) - rank(T);
    else
      c = size(T, 1) - rank(T, varargin{2});
    end
  end    
