function fdebug(msg,varargin)
%FDEBUG Utility function for debug output.
%   FDEBUG(Header,P1,...) print the string Header and the optional
%   parameters P1,...,Pn to standard error. The parameters can be a string,
%   scalar, or matrix.

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.

fprintf(2,'***************************************\n');
fprintf(2,'%s\n',msg);

for k = 1:nargin-1
  if ischar(varargin{k})
    fprintf(2,varargin{k});
  elseif isscalar(varargin{k})
    if isreal(varargin{k}) && ~mod(varargin{k},1)
      % A scalar integer
      fprintf(2,'%d',varargin{k});
    elseif isreal(varargin{k})
      fprintf(2,'%e',varargin{k});
    else
      fprintf(2,'%e %+ei',real(varargin{k}),imag(varargin{k}));
    end
  elseif isnumeric(varargin{k})
    A = varargin{k};
    [m,~] = size(A);
    fprintf(2,'\n');
    if isreal(A)
      for i = 1:m
        fprintf(2,'%+1.2e ',A(i,:));
        fprintf(2,'\n');
      end
    else
      for i = 1:m
        fprintf(2,'%+1.2e %+1.2ei   ',real(A(i,:)),imag(A(i,:)));
        fprintf(2,'\n');
      end
    end
    fprintf(2,'\n');
  end
end
fprintf(2,'***************************************\n\n');