%GSYLVE Solve the generalized Sylvester equation.
%   [X,Y] = GSYLVE(A,B,C,D,E,F) solves the generalized Sylvester linear
%   matrix equation
%
%         A*X - Y*B = Scale*C,
%   and
%         D*X - Y*E = Scale*F,
%
%   where A and D are M-by-M matrices, B and E are N-by-N matrices, and C,
%   F, X and Y are M-by-N matrices. The matrix pairs (A,D) and (B,E) are
%   asumed to be in generalized Schur form.
%
%   The scaling factor Scale, 0 <= Scale <= 1, is chosen to avoid overflow.
%   Normally, Scale = 1. If Scale is not equal to 1 a warning is issued. If
%   0 < Scale < 1, X and Y are the solutions to a system with slightly
%   perturbed C and F. If Scale = 0, X and Y is the solutions to the
%   homogeneous system with C = F = 0.
%
%   [X,Y,Dif] = GSYLVE(A,B,C,D,E,F) also returns a Frobenius norm-based
%   estimate Dif, which is an upper bound of Dif[(A,D),(B,E)] and measures
%   the separation of the spectrum of the matrix pair (A,D) from the
%   spectrum of the matrix pair (B,E).
%
%   [X,Y,Dif,Scale] = GSYLVE(A,B,C,D,E,F) also returns the scaling factor.
%   In this case, no warning is issued.
%
%   The mex-function calls the Lapacke routine ZTGSYL to do the
%   computations.
%