function varargout = isvd(A)
%ISVD Singular value decomposition in increasing order.
%   [U,S,V] = ISVD(X) produces a diagonal matrix S, of the same dimension
%   as X and with nonnegative diagonal elements in increasing order, and
%   unitary matrices U and V so that X = U*S*V'.
%  
%   S = ISVD(X) returns a vector containing the singular values.
%  
%   See also SVD.

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.

narginchk(1,1);
nargoutchk(0,3);

if nargout > 1
  [U,S,V] = svd(A);
  S = S(end:-1:1,:); %flipud
  varargout{2} = S(:,end:-1:1); %fliplr
  varargout{1} = U(:,end:-1:1); %fliplr
  if nargout > 2
    varargout{3} = V(:,end:-1:1); %fliplr
  end
else
  S = svd(A);
  varargout{1} = S(end:-1:1); %flipud
end

