function varargout  = ristr(G,H,tol,gap,setzero,rweyr,iweyr,forceimpose)
%RISTR RI-staircase form of the right singular and infinite eigenvalue blocks.
%   [RWeyr, IWeyr] = RISTR(G,H,Tol,Gap,SetZero) finds the right singular
%   blocks and the Jordan blocks with associated infinite eigenvalue in
%   G-sH with respect to Tol and Gap. Tol is a vector [TolG TolH], where
%   TolG is used for the column compression of G and TolH for the column
%   compression of H. The Weyr characteristics of the blocks are returned
%   in RWeyr and IWeyr, respectively. If the parameter SetZero is true, the
%   lower parts of the transformed G and H are forced to zero, otherwise
%   not.
%
%   [S,T,RWeyr,IWeyr] = RISTR(G,H,Tol,Gap,SetZero) also returns the
%   deflated S and T in the GUPTRI staircase form.
%
%   [S,T,P,Q,RWeyr,IWeyr] = RISTR(G,H,Tol,Gap,SetZero) also returns the
%   transformation matrices P and Q, such that P(S-sT)Q' = G-sH.
%
%   [S,T,Flag] = RISTR(G,H,Tol,Gap,SetZero,RWeyr,IWeyr,ForceImpose) returns
%   the deflated matrices S and T, with the imposed structure given by
%   RWeyr and IWeyr. If imposed separation succeeds, Flag is 0. If the
%   largest singular value imposed to zero is greater than Tol*Gap and
%   ForceImpose is false, Flag returns 1 and G and H are returned in S and
%   T, respectively. Otherwise, if ForceImpose is true, Flag returns 2 and
%   the singular values are forced to zero even if they are larger than
%   Tol*Gap.
%
%   [S,T,P,Q,Flag] = RISTR(G,H,Tol,Gap,SetZero,RWeyr,IWeyr,ForceImpose)
%   also returns the transformation matrices P and Q, used to form S and T.
%
%   [S,T,P,Q,E,F,Flag] = RISTR(G,H,Tol,Gap,SetZero,RWeyr,IWeyr,ForceImpose)
%   also returns the matrices E and F with the imposed permutations, such
%   that P(S-sT)Q' = (G+E)-s(H+F).
%
%   See also RZSTR, LISTR, LZSTR, FSTR.

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.

% Call rzstr with H-sG
varargout = cell(1,nargout);
if nargin == 5
  if nargout > 2
    [varargout{[2 1 3:end]}] = rzstr(H,G,[tol(2) tol(1)],gap,setzero); %#ok<*VARARG>
  else
    [varargout{:}] = rzstr(H,G,[tol(2) tol(1)],gap,setzero);
  end
else
  if nargout == 2
    [varargout{[2 1]}] = rzstr(H,G,[tol(2) tol(1)],gap,setzero,rweyr,iweyr,forceimpose);
  elseif nargout < 7
    [varargout{[2 1 3:end]}] = rzstr(H,G,[tol(2) tol(1)],gap,setzero,rweyr,iweyr,forceimpose);
  else
    [varargout{[2 1 3 4 6 5 7]}] = rzstr(H,G,[tol(2) tol(1)],gap,setzero,rweyr,iweyr,forceimpose);
  end    
end
