function [c] = mcodim(X, varargin)
%MCODIM Codimension of a matrix space.
%   MCODIM(A) computes the codimension of the tangent space of the
%   similarity orbit of a square matrix A. Default tolerance parameter for
%   RANK is used.
%
%   MCODIM(A,Tol) uses the specified tolerance Tol. 
%
%   MCODIM(Mstr) determines the codimension of the orbit of a matrix
%   structure object Mstr. The codimension is determined with respect to
%   the represented canonical structure not the tangent space.
%
%   See also MTANSPACE, MSTRUCT/CODIM, PCODIM.

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.

narginchk(1,2);
nargoutchk(0,1);

if isa(X,'mstruct')
  % Argument X is a matrix structure object
  c = codim(X,varargin{:});
else
  % Argument X is a matrix
  T = mtanspace(X);
  if nargin == 1
    c = size(T, 1) - rank(T, tol);
  else
    c = size(T, 1) - rank(T);
  end
end

