function blocklist = mcsgetvalidblocks(structhandle)
%MCSGETVALIDBLOCKS Return a list of available canonical blocks.
%   MCSGETVALIDBLOCKS returns a list of all available canonical block
%   objects.
%
%   MCSGETVALIDBLOCKS(StructHandle) returns the list of valid canonical
%   block objects for the specified canonical structure StructHandle, where
%   StructHandle can be a canonical structure object, the name of the
%   canonical structure class as a string, or the class given as a
%   meta.class object.
%
%   See also MCSSTRUCT/GETVALIDBLOCKS, META.CLASS.

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.
      
if nargin == 0 || (ischar(structhandle) && strcmpi(structhandle,'mcsstruct'))
  curdir = which('mcsblock');
  curdir = fileparts(curdir);
  
  ds = dir([curdir '/*.m']);
  k = 0;
  blocklist = {};
  for i = 1:length(ds)
    if ~strcmp(ds(i).name,{'block_template.m','mcsblock.m'})
      k = k+1;
      [~,blocklist{k}] = fileparts(ds(i).name);
    end
  end
elseif ischar(structhandle)
  ob = meta.class.fromName(structhandle);
  pCBlocks = findobj(ob.PropertyList,'Name','cblocks');
  blocklist = pCBlocks.DefaultValue; % get values from cblocks
elseif isa(structhandle,'mcsstruct')
  blocklist = structhandle.cblocks;
else
  % Assume it is a meta.class object
  plist = structhandle.PropertyList;
  blocklist = plist(2).DefaultValue; % get values from cblocks
end

      
