function [T] = mtanspace(A)
%MTANSPACE Tangent space of the orbit of a matrix.
%   T = MTANSPACE(A) returns the matrix representation 
%
%      T = kron(A.',I) - kron(I_n,A) 
%
%   of the tangent space to the similarity orbit(A) at A, where A is an
%   n-by-n matrix and I_n is the n-by-n identity matrix. The tangent space
%   is the range of the (n^2)-by-(n^2) matrix T.
%
%   The tangent space consists of the matrices of the form 
%      T_A = X*A - A*X,
%   where X is an n-by-n matrix. Equivalently, the tangent vectors T_A can
%   be represented as 
%      vec(T_A) = T * vec(X).
% 
%   See also MCODIM, PTANSPACE.

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.
 
narginchk(1,1)
nargoutchk(0,1)
[m,n] = size(A);
if m ~= n
  error('MCS:mtanspace','Matrix must be square.')
end

In = eye(size(A,1));

T = kron(A.',In)-kron(In,A);
