function [c] = pcodim(varargin)
%PCODIM Codimension of a matrix pencil orbit.
%   PCODIM(G,H) computes the codimension of the tangent space of the strict
%   equivalence orbit of a matrix pencil G-sH. Default tolerance parameter
%   of RANK is used.
%
%   PCODIM(G,H,Tol) uses the specified tolerance Tol. 
%
%   PCODIM(Pstr) determines the codimension of the orbit of the matrix
%   pencil structure object Pstr. The codimension is determined with
%   respect to the represented canonical structure not the tangent space.
%   For further information, see PSTRUCT/CODIM.
%
%   See also PTANSCPACE, PSTRUCT/CODIM, MCODIM.

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.
  
nargoutchk(0,1);

if isa(varargin{1},'pstruct')
  c = codim(varargin{:});
else
  narginchk(2,3);
  
  G   = varargin{1};
  H   = varargin{2};
  T = ptanspace(G,H);
  if nargin == 2
    % Use default tolerance in rank
    c = size(T, 1) - rank(T);
  else
    c = size(T, 1) - rank(T, varargin{3});
  end
end
