function [type,A,X,n,x,narg] = pairchk(varargin)
%PAIRCHK Check dimensions and type of a matrix pair.

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.

  if length(varargin) < 2
    error('Not enough input arguments.');
  end
  if ischar(varargin{1})
    if nargin < 3
      error('Not enough input arguments.');
    end
    switch lower(varargin{1})
     case {'ab','ctrb'}
      type = 'ab';
     case {'ac','obsv'}
      type = 'ac';
     otherwise
      error(['''TYPE'' must be either ''ab'', ''ac'', '...
            '''ctrb'', or ''obsv''.']);
    end
    A = varargin{2};
    X = varargin{3};
    narg = 3;
  else
    type = '';
    A = varargin{1};
    X = varargin{2};
    narg = 2;
  end
  
  [ma,na] = size(A);
  [mx,nx] = size(X);
  if ma ~= na
    error('A must be square');
  end
  
  if isempty(type);
    if ma == mx
      type = 'ab';    
    elseif na == nx
      type = 'ac';
    else
      error(['A and B (or C) must have the same number of rows' ...
            ' (or columns).']);
    end
  end
  
  switch type
   case 'ab'
    if ma ~= mx
      error('A and B must have the same number of rows.');
    end
    if nx == 0
      error('B must have at least one column.');
    end
    n = ma;
    x = nx;
   case 'ac'
    if na ~= nx
      error('A and C must have the same number of columns.');
    end
    if mx == 0
      error('C must have at least one row.');
    end
    n = na;
    x = mx;
  end