function [c] = scmcodim(varargin)
%SCMCODIM Codimension of a matrix orbit under *congruence.
%   SCMCODIM(H) computes the codimension of the tangent space of the
%   *congruence orbit of a matrix H over the field of real numbers. Default
%   tolerance parameter of RANK is used.
%
%   SCMCODIM(H,Tol) uses the specified tolerance Tol. 
%
%   SCMCODIM(SCMstr) determines the codimension of the orbit of the
%   *congruence matrix structure object SCMstr. The codimension is
%   determined with respect to the represented canonical structure not the
%   tangent space. For further information, see SCMSTRUCT/CODIM.
%
%   See also SCMSTRUCT/CODIM, MCODIM.

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.
  
  nargoutchk(0,1);

  if isa(varargin{1},'scmstruct')
    c = codim(varargin{:});
  else
    narginchk(1,2);
    
    A = varargin{1};
    T = scmtanspace(A);
    if nargin == 1
      % Use default tolerance in rank
      c = size(T, 1) - rank(T);
    else
      c = size(T, 1) - rank(T, varargin{2});
    end
  end    
