function weyr = segre2weyr(segre,type)
%SEGRE2WEYR Weyr from Segre characteristics.
%   SEGRE2WEYR(Segre,Type) converts an array with the block sizes given in
%   Segre characteristics to an array with their sizes presented in Weyr
%   characteristics. The parameter Type gives the type of the blocks and
%   can be:
%      'regular'  for regular (Jordan-type) blocks,
%      'singular' for singular blocks.
%
%   See also WEYR2SIZES, WEYR2SEGRE, SIZES2WEYR, SIZES2SEGRE.  

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.

narginchk(2,2);
nargoutchk(0,1);

if iscell(segre) && length(segre) == 1
  segre = segre{1};
end
if min(size(segre)) > 1
  error('Argument must be a vector');
end
if size(segre,1) > 1
  segre = segre';
end


switch type
  case {'regular'}
    offset = 0;
  case {'singular'}
    offset = 1;
  otherwise
    error('Unknown type');
end

weyr = [];
if ~isempty(segre)
  r = segre(1) + offset;
  weyr = ones(1,r);
end
for i = 2:length(segre)
  r = segre(i) + offset;
  weyr(1:r) = weyr(1:r) + ones(1,r);
end
