function weyr = sizes2weyr(sizes,type)
%SIZES2WEYR Weyr characteristics from block sizes.
%   SIZESE2WEYR(Sizes,Type) converts an array with the block sizes to an
%   array with their sizes represented in Weyr characteristics. The
%   parameter Type gives the type of the blocks and can be:
%      'regular'  for regular (Jordan-type) blocks,
%      'singular' for singular blocks.
%
%   See also WEYR2SIZES, WEYR2SEGRE, SEGRE2WEYR, SIZES2SEGRE.  

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.

narginchk(2,2);
nargoutchk(0,1);
if iscell(sizes) && length(sizes) == 1
  sizes = sizes{1};
end
if ~isvector(sizes)
  error('MCS:sizes2weyr','SIZES must be a vector.');
end

weyr = segre2weyr(sort(sizes,'descend'),type);
