function [c] = spcodim(varargin)
%SPCODIM Codimension of a symmetric matrix pencil orbit.
%   SPCODIM(G,H) computes the codimension of the tangent space to the
%   congruence orbit of a symmetric matrix pencil G-sH. Default tolerance 
%   parameter of RANK is used.
%
%   SPCODIM(G,H,Tol) uses the specified tolerance Tol. 
%
%   SPCODIM(SPstr) determines the codimension of the congruence orbit of the
%   symmetric  matrix pencil structure object SPstr. The codimension is 
%   determined with respect to the represented canonical structure not the 
%   tangent space. For further information, see SPSTRUCT/CODIM.
%
%   See also PSTRUCT/CODIM, SSPCODIM.

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.
  
  nargoutchk(0,1);

  if isa(varargin{1},'spstruct')
    c = codim(varargin{:});
  else
    narginchk(2,3);
    
    A   = varargin{1};
    B   = varargin{2};
    T = sptanspace(A,B);
    [n,~]=size(A);
    if nargin == 2
      % Use default tolerance in rank
      c = size(T, 2) - rank(T) + n;
    else
      c = size(T, 2) - rank(T, varargin{3}) + n;
    end
  end    
