function [c] = sspcodim(varargin)
%SSPCODIM Codimension of a skew-symmetric matrix pencil orbit.
%   SSPCODIM(G,H) computes the codimension of the tangent space of the
%   congruence orbit of a skew-symmetric matrix pencil G-sH. Default 
%   tolerance parameter of RANK is used.
%
%   SSPCODIM(G,H,Tol) uses the specified tolerance Tol. 
%
%   SSPCODIM(SSPstr) determines the codimension of the congruence orbit of 
%   the skew-symmetric matrix pencil structure object SSPstr. The 
%   codimension is determined with respect to the represented canonical 
%   structure not the tangent space. 
%
%   See also PSTRUCT/CODIM, MCODIM.

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.
  
  nargoutchk(0,1);

  if isa(varargin{1},'sspstruct')
    c = codim(varargin{:});
  else
    narginchk(2,3);
    
    A   = varargin{1};
    B   = varargin{2};
    T = sptanspace(A,B);
    [n,~]=size(A);
    if nargin == 2
      % Use default tolerance in rank
      c = size(T, 2) - rank(T) - n;
    else
      c = size(T, 2) - rank(T, varargin{3}) - n;
    end
  end    
