function segre = weyr2segre(weyr,type)
%WEYR2SEGRE Segre from Weyr characteristics.
%   WEYR2SEGRE(Weyr,Type) converts an array with the block sizes given in
%   Weyr characteristics to an array with the blocks' sizes in Segre
%   characteristics, i.e., the sizes of the blocks sorted in non-increasing
%   order. The parameter Type gives the type of the blocks and can be:
%      'regular'  for regular (Jordan-type) blocks,
%      'singular' for singular blocks.
%
%   See also WEYR2SIZES, SEGRE2WEYR, SIZES2WEYR, SIZES2SEGRE.  

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.

narginchk(2,2);
nargoutchk(0,1);
if ~isvector(weyr) || ~issorted(fliplr(weyr))
  error('MCS:weyr2segre','Weyr must be a vector in non-increasing order.');
end

switch type
  case 'regular'
    offset = 0;
  case 'singular'
    offset = -1;
  otherwise
    error('Unknown type');
end

if ~isempty(weyr)
  r = weyr(1);
  segre = ones(1,r) + offset;
else
  segre = [];
end

for i = 2:length(weyr)
  r = weyr(i);
  segre(1:r) = segre(1:r) + ones(1,r);
end
