function sizes = weyr2sizes(weyr,type)
%WEYR2SIZES Block sizes from Weyr characteristics.
%   WEYR2SIZES(Weyr,Type) converts an array with the block sizes given in
%   Weyr characteristics to an array with the blocks' sizes. The parameter
%   Type gives the type of the blocks and can be:
%      'regular'  for regular (Jordan-type) blocks,
%      'singular' for singular blocks.
%
%   See also WEYR2SEGRE, SEGRE2WEYR, SIZES2WEYR, SIZES2SEGRE.  

% This file is part of the Matrix Canonical Structure (MCS) Toolbox for Matlab.
% MCS Toolbox is a freely-available software package licensed under the modified
% BSD license.

narginchk(2,2);
nargoutchk(0,1);
if ~isvector(weyr)
  error('MCS:weyr2sizes','Weyr must be a vector.');
end

switch type
  case {'regular'}
    offset = 0;
  case {'singular'}
    offset = -1;
  otherwise
    error('Unknown type');
end

sizes = [];
if ~isempty(weyr)
  r = weyr(1);
  sizes = ones(1,r) + offset;
end
for i = 2:length(weyr)
  r = weyr(i);
  sizes(1:r) = sizes(1:r) + ones(1,r);
end
